
use strict;

package Alpha::Beta::Gamma;

sub Test {
    print "this is testrem\n";
}
